@@ -8,7 +8,7 @@ from pequod_cli.manager.cli import manager
 from pequod_cli.registry.cli import registry
 from pequod_cli.replicator.cli import replicator
 from pequod_cli.service import CORE_DOMAINS
-from pequod_cli.utils import AliasedGroup
+from pequod_cli.utils import AliasedGroup, find_cacert_bundle
 import click
 import logging
 import os
@@ -105,6 +105,9 @@ def login(click_context, endpoints, username, password, cacert):
     """
     click.secho('Trying authenticating to core services..', bold=True, fg='blue')
 
+    if not cacert:
+        cacert = find_cacert_bundle()
+
     credentials = {'username': username, 'password': password}
     ctx = click_context.obj
     ctx = Context(ctx.config_file, ctx.cluster, endpoints, credentials, cacert)
