@@ -62,6 +62,47 @@ def parse_version(v):
     return tuple([int(x) for x in v.split(".")])
 
 
+def get_latest_template_version(manager, template_name):
+    # special case: find out latest template and use it
+    latest_version = '0'
+    for row in manager.get_templates():
+        if row['template_name'] == template_name:
+            # TODO: only supports numeric versions right now :-P
+            try:
+                if parse_version(row['template_version']) > parse_version(latest_version):
+                    latest_version = row['template_version']
+            except ValueError:
+                # ignore non-int versions
+                pass
+    return latest_version
+
+
+@nodes.command('add')
+@click.argument('node_name')
+@click.argument('mac')
+@click.argument('ipv4')
+@click.argument('ipv6')
+@click.argument('template_name')
+@click.option('--template-version', help='Use specific template version')
+@click.pass_obj
+def add_node(ctx, node_name, mac, ipv4, ipv6, template_name, template_version):
+    """
+    Add a new app node configuration, uses latest template version by default.
+    """
+    if not template_version:
+        template_version = get_latest_template_version(ctx.manager, template_name)
+    data = {
+        'mac': mac,
+        'ipv4': ipv4,
+        'ipv6': ipv6,
+        'template_name': template_name,
+        'template_version': template_version,
+    }
+    action('Adding node {node_name} with MAC address {mac}..', **vars())
+    ctx.manager.put('/nodes/{}'.format(node_name), data=data)
+    ok()
+
+
 @nodes.command()
 @click.argument('node_name_pattern')
 @click.argument('key_value', nargs=-1)
@@ -82,18 +123,7 @@ def update(ctx, node_name_pattern, key_value):
             if key not in data:
                 raise click.UsageError('Invalid key: "{}" is not allowed'.format(key))
             if key == 'template_version' and val == 'latest':
-                # special case: find out latest template and use it
-                latest_version = '0'
-                for row in ctx.manager.get_templates():
-                    if row['template_name'] == data['template_name']:
-                        # TODO: only supports numeric versions right now :-P
-                        try:
-                            if parse_version(row['template_version']) > parse_version(latest_version):
-                                latest_version = row['template_version']
-                        except ValueError:
-                            # ignore non-int versions
-                            pass
-                val = latest_version
+                val = get_latest_template_version(ctx.manager, data['template_name'])
             data[key] = val
         action('Updating {}..'.format(node_name))
         ctx.manager.put('/nodes/{}'.format(node_name), data=data)
